/*  Glimmer - toolbar.h
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _TOOLBAR_H_
#define _TOOLBAR_H_

#ifdef __cplusplus
extern "C" {
#endif

#include "declarations.h"

void make_toolbars(void);
void setup_toolbar_style(void);
extern GtkWidget *filebar;
extern GtkWidget *editbar;
extern GtkWidget *buildbar;
#ifdef WITH_PYTHON
extern GtkWidget *customnotebook;
extern GList *custombars;
extern GList *custombaritems;
extern GtkWidget *custombar;
#endif
extern GtkWidget *filebar_new;
extern GtkWidget *filebar_open;
extern GtkWidget *filebar_close;
extern GtkWidget *filebar_save;
extern GtkWidget *filebar_saveas;
extern GtkWidget *editbar_undo;
extern GtkWidget *editbar_redo;
extern GtkWidget *editbar_cut;
extern GtkWidget *editbar_copy;
extern GtkWidget *editbar_paste;
extern GtkWidget *editbar_properties;
extern GtkWidget *buildbar_compile;
extern GtkWidget *buildbar_kill_compile;
extern GtkWidget *buildbar_debug;
extern GtkWidget *buildbar_kill_debug;
extern GtkWidget *buildbar_execute;
extern GtkWidget *buildbar_kill_exec;

#ifdef __cplusplus
}
#endif

#endif
